@@ -12,16 +12,20 @@ use constant FSTAB_LENGTH => 6;
 
 ##no critic (InputOutput::ProhibitBacktickOperators)
 
-$VERSION = '0.74';
+$VERSION = '0.76';
 
-my %OSVERSION; # cache
+sub init {
+    my $self = shift;
+    $self->{OSVERSION}  = undef; # see _populate_osversion
+    $self->{FILESYSTEM} = undef; # see _populate_fs
+    return;
+}
 
 # unimplemented
 sub logon_server {}
 
 sub edition {
-    my $self = shift->_populate_osversion;
-    return $OSVERSION{RAW}->{EDITION};
+    return shift->_populate_osversion->{OSVERSION}{RAW}{EDITION};
 }
 
 sub tz {
@@ -32,8 +36,7 @@ sub tz {
 }
 
 sub meta {
-    my $self = shift;
-    $self->_populate_osversion();
+    my $self = shift->_populate_osversion;
 
     require POSIX;
     require Sys::Info::Device;
@@ -44,12 +47,12 @@ sub meta {
     my @swaps = $self->_parse_swap;
     my %info;
 
-    $info{manufacturer}              = $OSVERSION{MANUFACTURER};
+    $info{manufacturer}              = $self->{OSVERSION}{MANUFACTURER};
     $info{build_type}                = undef;
     $info{owner}                     = undef;
     $info{organization}              = undef;
     $info{product_id}                = undef;
-    $info{install_date}              = $OSVERSION{RAW}->{BUILD_DATE};
+    $info{install_date}              = $self->{OSVERSION}{RAW}{BUILD_DATE};
     $info{boot_device}               = undef;
 
     $info{physical_memory_total}     = $mem{MemTotal};
@@ -81,17 +84,14 @@ sub tick_count {
 sub name {
     my($self, @args) = @_;
     $self->_populate_osversion;
-    my %opt  = @args % 2 ? () : @args;
-    my $id   = $opt{long} ? ($opt{edition} ? 'LONGNAME_EDITION' : 'LONGNAME')
-             :              ($opt{edition} ? 'NAME_EDITION'     : 'NAME'    )
-             ;
-    return $OSVERSION{ $id };
+    my %opt  = @args % 2  ? ()         : @args;
+    my $id   = $opt{long} ? 'LONGNAME' : 'NAME';
+    return $self->{OSVERSION}{ $opt{edition} ? $id . '_EDITION' : $id };
 }
 
-
-sub version   { shift->_populate_osversion(); return $OSVERSION{VERSION}      }
-sub build     { shift->_populate_osversion(); return $OSVERSION{RAW}->{BUILD_DATE} }
-sub uptime    {                               return time - shift->tick_count }
+sub version   { return shift->_populate_osversion->{OSVERSION}{VERSION}         }
+sub build     { return shift->_populate_osversion->{OSVERSION}{RAW}{BUILD_DATE} }
+sub uptime    { return time - shift->tick_count }
 
 # user methods
 sub is_root {
@@ -198,8 +198,8 @@ sub _ip {
 }
 
 sub _populate_osversion {
-    return if %OSVERSION;
     my $self = shift;
+    return $self if $self->{OSVERSION};
     require Sys::Info::Driver::Linux::OS::Distribution;
     my $distro     = Sys::Info::Driver::Linux::OS::Distribution->new;
     my $osname     = $distro->name;
@@ -209,28 +209,26 @@ sub _populate_osversion {
     my $build      = $distro->build;
     my $build_date = $distro->build_date;
 
-    %OSVERSION  = (
+    $self->{OSVERSION} = {
         NAME             => $osname,
         NAME_EDITION     => $edition ? "$osname ($edition)" : $osname,
         LONGNAME         => q{}, # will be set below
         LONGNAME_EDITION => q{}, # will be set below
-        VERSION  => $V,
-        KERNEL   => $kernel,
-        RAW      => {
-                        BUILD      => defined $build      ? $build      : 0,
-                        BUILD_DATE => defined $build_date ? $build_date : 0,
-                        EDITION    => $edition,
-                    },
-        MANUFACTURER => $distro->manufacturer,
-    );
+        VERSION          => $V,
+        KERNEL           => $kernel,
+        MANUFACTURER     => $distro->manufacturer,
+        RAW              => {
+            BUILD      => defined $build      ? $build      : 0,
+            BUILD_DATE => defined $build_date ? $build_date : 0,
+            EDITION    => $edition,
+        },
+    };
 
-    $OSVERSION{LONGNAME}         = sprintf '%s %s (kernel: %s)',
-                                   @OSVERSION{ qw/ NAME         VERSION / },
-                                   $kernel;
-    $OSVERSION{LONGNAME_EDITION} = sprintf '%s %s (kernel: %s)',
-                                   @OSVERSION{ qw/ NAME_EDITION VERSION / },
-                                   $kernel;
-    return;
+    my $o = $self->{OSVERSION};
+    my $t = '%s %s (kernel: %s)';
+    $o->{LONGNAME}         = sprintf $t, $o->{NAME},         $o->{VERSION}, $kernel;
+    $o->{LONGNAME_EDITION} = sprintf $t, $o->{NAME_EDITION}, $o->{VERSION}, $kernel;
+    return $self;
 }
 
 sub _fs_attributes {
@@ -288,8 +286,8 @@ Sys::Info::Driver::Linux::OS - Linux backend
 
 =head1 DESCRIPTION
 
-This document describes version C<0.74> of C<Sys::Info::Driver::Linux::OS>
-released on C<15 January 2010>.
+This document describes version C<0.76> of C<Sys::Info::Driver::Linux::OS>
+released on C<18 July 2010>.
 
 -
 
@@ -305,6 +303,8 @@ Please see L<Sys::Info::OS> for definitions of these methods and more.
 
 =head2 fs
 
+=head2 init
+
 =head2 is_root
 
 =head2 login_name
@@ -344,7 +344,7 @@ Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
